import { __rest } from "tslib";
import React, { useState, useEffect, useCallback } from 'react';
import { Animated } from 'react-native';
import { isEmpty } from 'lodash';
import { colors } from '../../theme';
import { usePrevious } from '../../hooks';
import { InputStatus } from '../../types';
import MaskedInput from './MaskedInput';
import { Label, Wrapper, TextInput, BottomLine, InputAreaWrapper, LABEL_UPPER_STYLE, LABEL_LOWER_STYLE, } from './styles';
import Icon from '../Icon';
import FormError from '../FormError';
const AnimatedTextInput = (_a) => {
    var { big = false, contrast = false, borderless = false, multiline = false, keyboardType = 'default', iconSize = 20, iconTouchableEnabled = false, status = InputStatus.Default, maskType = null, iconName = '', label = '', value = '', placeholder = '', error = '', style = {}, textStyle = {}, iconHitSlop = {}, inputRef = React.createRef(), onBlur = () => { }, onFocus = () => { }, onChangeText = () => { }, onPressIcon = () => { } } = _a, rest = __rest(_a, ["big", "contrast", "borderless", "multiline", "keyboardType", "iconSize", "iconTouchableEnabled", "status", "maskType", "iconName", "label", "value", "placeholder", "error", "style", "textStyle", "iconHitSlop", "inputRef", "onBlur", "onFocus", "onChangeText", "onPressIcon"])
    // eslint-disable-next-line sonarjs/cognitive-complexity
    ;
    const [labelAnimatedStyle] = useState({
        top: new Animated.Value(LABEL_LOWER_STYLE.top),
        fontSize: new Animated.Value(LABEL_LOWER_STYLE.fontSize),
    });
    const [isPlaceholder, setIsPlaceHolder] = useState(true);
    const animateComponent = useCallback((updatedLabelStyle) => {
        const animations = Object.keys(updatedLabelStyle).map((animationProp) => Animated.timing(labelAnimatedStyle[animationProp], {
            toValue: updatedLabelStyle[animationProp],
            duration: 200,
            useNativeDriver: false,
        }));
        Animated.parallel(animations).start();
    }, [labelAnimatedStyle]);
    const animationUp = () => {
        animateComponent(LABEL_UPPER_STYLE);
    };
    const animationDown = () => {
        animateComponent(LABEL_LOWER_STYLE);
    };
    const getIconColor = (hasError) => {
        if (hasError) {
            return colors.failure;
        }
        return colors.primary.contrast;
    };
    const handleOnFocus = () => {
        if (isPlaceholder) {
            setIsPlaceHolder(false);
            animationUp();
        }
        onFocus();
    };
    const handleOnBlur = () => {
        const isEmptyLabel = label === '';
        if (!value && !isEmptyLabel) {
            setIsPlaceHolder(true);
            animationDown();
        }
        if (isEmptyLabel) {
            setIsPlaceHolder(false);
        }
        onBlur();
    };
    const renderTextInput = (inputStatus) => {
        const renderPlaceholder = !value && !isPlaceholder ? placeholder : '';
        const textInputProps = Object.assign(Object.assign({}, rest), { big,
            contrast,
            borderless,
            multiline,
            value,
            keyboardType,
            onChangeText, status: inputStatus, placeholder: renderPlaceholder, style: textStyle, onBlur: handleOnBlur, onFocus: handleOnFocus, underlineColorAndroid: 'transparent' });
        return maskType ? (<MaskedInput inputRef={inputRef} maskType={maskType} {...textInputProps}/>) : (<TextInput ref={inputRef} {...textInputProps}/>);
    };
    const previousValue = usePrevious(value || '');
    useEffect(() => {
        const wasEmpty = (previousValue === null || previousValue === void 0 ? void 0 : previousValue.length) === 0;
        if (value && value.length && wasEmpty) {
            animationUp();
        }
        if (label === '') {
            setIsPlaceHolder(false);
        }
    }, [value, previousValue]);
    const hasError = !isEmpty(error);
    const icon = iconName;
    const iconColor = getIconColor(hasError);
    const renderStatus = hasError ? InputStatus.Failure : status;
    return (<Wrapper style={style} multiline={multiline}>
      <FormError error={error}>
        <Label status={status} contrast={contrast} style={labelAnimatedStyle} isPlaceholder={isPlaceholder}>
          {label}
        </Label>
        <InputAreaWrapper multiline={multiline}>
          {renderTextInput(renderStatus)}
          {!isEmpty(icon) ? (<Icon size={iconSize} name={icon} color={iconColor} touchable={iconTouchableEnabled} onPress={onPressIcon} hitSlop={iconHitSlop}/>) : null}
        </InputAreaWrapper>
        {!borderless && <BottomLine status={status} contrast={contrast}/>}
      </FormError>
    </Wrapper>);
};
export default AnimatedTextInput;
//# sourceMappingURL=index.js.map